function [h0,h1,h2,z0,z1,z2] = MakeFilters(k1,k2,arg3)

% [h0,h1,h2,z0,z1,z2] = MakeFilters(k1,k2)
% use MakeFilters(k1,k2,'mid') for mid-phase spectral factorization.
%
% % EXAMPLE
% [h0,h1,h2,z0,z1,z2] = MakeFilters(1,3);
% figure(1), plot_wlets(h0,h1,h2,z0,z1,z2);
% figure(2), plot_H(h0,h1,h2);

MID = 0;
if nargin > 2
    if strcmp(arg3,'mid')
        MID = 1;
    end
end

k0 = k1+k2;

[tmp,tmp2,ar] = maxflatI(k0,k2-1);
[tmp,tmp2,br] = maxflatI(k2,k0-1);

ar = 2*ar;
br = 2*symmod(br);

if MID == 1
    a = sfact_mid(ar);
else
    a = sfact(ar);
end

h0 = conv(blp(k0),a);
h1 = conv(blp(k1),conv(bhp(k2),modflip(a)));

cr = br - conv(blp(2*k1),symmod(ar));
cr = cr(2:end-1);
if MID == 1
    c = sfact_mid(cr);
    % c = c(end:-1:1);
else
    c = sfact(cr);
    c = c(end:-1:1);
end
h2 = conv(bhp(k2),c)/sqrt(2);
h2 = [h2 0];

if max(h1)+min(h1)<0, h1 = -h1; end
if max(h2)+min(h2)<0, h2 = -h2; end

% check:
[m0 m1] = checkPR(h0,h1,h2);
disp([m0 m1])

z0 = [-ones(k0,1); roots(a)];
z1 = [-ones(k1,1); ones(k2,1); -1./roots(a)];
z2 = [ones(k2,1); roots(c)];


