function plotwlets(h0,h1,h2,z0,z1,z2)

if nargin < 4, z0 = roots(h0); end
if nargin < 5, z1 = roots(h1); end
if nargin < 6, z2 = roots(h2); end

[H0,w] = freqz(h0);
[H1,w] = freqz(h1);
[H2,w] = freqz(h2);

[w1,s,t] = wletfn(h0,h1);
[w2,s,t] = wletfn(h0,h2);
N = length(h0);

clf
fsa = 6;
R = 4;
ms = 3;

title_fs = 7; % title font size

% FREQUENCY RESPONSE PLOTS

ax = [0 1 0 1.5];
subplot(R,4,1)
plot(w/pi,abs(H0));
set(gca,'fontsize',fsa)
title('|H_0(e^{j\omega})|','fontsize',title_fs);
axis(ax)

subplot(R,4,5)
plot(w/pi,abs(H1));
set(gca,'fontsize',fsa)
title('|H_1(e^{j\omega})|','fontsize',title_fs);
axis(ax)

subplot(R,4,9)
plot(w/pi,abs(H2));
set(gca,'fontsize',fsa)
title('|H_2(e^{j\omega})|','fontsize',title_fs);
axis(ax)

% ZPLANE PLOTS

subplot(R,4,2), 
[p1,p2,p3] = zplane(z0); xlabel(''); ylabel('');
if length(p3)>1, set(p3(2),'fontsize',8); end
set(gca,'fontsize',fsa)
set(p1,'markersize',ms);
title('Zeros of H_0(z)','fontsize',title_fs)

subplot(R,4,6), 
[p1,p2,p3] = zplane(z1); xlabel(''); ylabel('');
set(gca,'fontsize',fsa)
set(p1,'markersize',ms);
if length(p3)> 2, set(p3(3),'fontsize',8), end
title('Zeros of H_1(z)','fontsize',title_fs)

subplot(R,4,10), 
[p1,p2,p3] = zplane(z2); xlabel(''); ylabel('');
set(gca,'fontsize',fsa)
set(p1,'markersize',ms);
if length(p3)>1, set(p3(2),'fontsize',8), end
if length(p3)>2, set(p3(3),'fontsize',8), end
title('Zeros of H_2(z)','fontsize',title_fs)

% STEM PLOTS

ax = [-1 N -1 1.0];
subplot(R,4,3), stem(0:N-1,h0,'.'), axis(ax)
set(gca,'fontsize',fsa)
title('h_0(n)','fontsize',title_fs)
subplot(R,4,7), stem(0:N-1,h1,'.'), axis(ax)
set(gca,'fontsize',fsa)
title('h_1(n)','fontsize',title_fs)
subplot(R,4,11), stem(0:N-1,h2,'.'), axis(ax)
set(gca,'fontsize',fsa)
title('h_2(n)','fontsize',title_fs)

% WAVELET PLOTS

ax0 = [0 N-1 -0.5 1.5];
ax = [0 N-1 -1 1.0];
subplot(R,4,4), plot(t,s),  axis(ax0)
set(gca,'fontsize',fsa)
title('\phi(t)','fontsize',title_fs)
subplot(R,4,8), plot(t,w1), axis(ax)
set(gca,'fontsize',fsa)
title('\psi_1(t)','fontsize',title_fs)
subplot(R,4,12), plot(t,w2), axis(ax)
set(gca,'fontsize',fsa)
title('\psi_2(t)','fontsize',title_fs)

orient landscape



